@@ -1,4 +1,4 @@
-import random
+import random ; random.seed()
 import simplejson
 import pkg_resources
 
@@ -19,7 +19,7 @@ class TurboFlot(Widget):
         </script>
       </div>
     """
-    params = ["data", "options", "height", "width"]
+    params = ["data", "options", "height", "width", "id"]
     params_doc = {
             "data"    : "An array of data series",
             "options" : "Plot options",
@@ -30,9 +30,11 @@ class TurboFlot(Widget):
                   JSLink("turboflot", "jquery.js"),
                   JSLink("turboflot", "jquery.flot.js")]
 
-    def __init__(self, data, options={}, height="300px", width="600px"):
-        random.seed()
-        self.id = int(random.random() * 1000)
+    def __init__(self, data, options={}, height="300px", width="600px", id=None):
+        if id:
+            self.id = id
+        else:
+            self.id = int(random.random() * 1000)
         self.data = simplejson.dumps(data)
         self.options = simplejson.dumps(options)
         self.height = height
